From bf78cd4ba84e7399f6c478010942c6952ee337f9 Mon Sep 17 00:00:00 2001
From: Chris Lamb <chris@chris-lamb.co.uk>
Date: Wed, 24 Oct 2018 17:45:33 -0400
Subject: [PATCH 1/2] Ensure that we call our hit counter before following the
 link. (re. #note-7 of #14922)

---
 wiki/src/install/inc/js/download.js | 37 ++++++++++++++++++++---------
 1 file changed, 26 insertions(+), 11 deletions(-)

diff --git a/wiki/src/install/inc/js/download.js b/wiki/src/install/inc/js/download.js
index b70b293498..2d688c00a3 100644
--- a/wiki/src/install/inc/js/download.js
+++ b/wiki/src/install/inc/js/download.js
@@ -268,10 +268,15 @@ document.addEventListener("DOMContentLoaded", function() {
   opaque(document.getElementById("continue-link-bittorrent"));
 
   // Display "Verify with your browser" when ISO image is clicked
-  document.getElementById("download-iso").onclick = function() {
-    hitCounter("download-iso");
-    toggleDirectBitTorrent("direct");
-    resetVerificationResult();
+  document.getElementById("download-iso").onclick = function(e) {
+    try {
+      e.preventDefault();
+      hitCounter("download-iso");
+      toggleDirectBitTorrent("direct");
+      resetVerificationResult();
+    } finally {
+      window.location = this.getAttribute("href");
+    }
   }
 
   // Display "Verify with your browser" when "I already" is clicked
@@ -282,16 +287,26 @@ document.addEventListener("DOMContentLoaded", function() {
   }
 
   // Reset verification when downloading again after failure
-  document.getElementById("download-iso-again").onclick = function() {
-    hitCounter("download-iso-again");
-    toggleDirectBitTorrent("direct");
-    resetVerificationResult();
+  document.getElementById("download-iso-again").onclick = function(e) {
+    try {
+      e.preventDefault();
+      hitCounter("download-iso-again");
+      toggleDirectBitTorrent("direct");
+      resetVerificationResult();
+    } finally {
+      window.location = this.getAttribute("href");
+    }
   }
 
   // Display "Verify with BitTorrent" when Torrent file is clicked
-  document.getElementById("download-torrent").onclick = function() {
-    hitCounter("download-torrent");
-    toggleDirectBitTorrent("bittorrent");
+  document.getElementById("download-torrent").onclick = function(e) {
+    try {
+      e.preventDefault();
+      hitCounter("download-torrent");
+      toggleDirectBitTorrent("bittorrent");
+    } finally {
+      window.location = this.getAttribute("href");
+    }
   }
 
   // Install Chrome extension when clicking "chrome" links
-- 
2.19.1

